.. VY4E-OptModel documentation master file, created by Erik Alvarez

Contact Us
==========

`Erik Alvarez <https://erikfilias.github.io/>`_

erik.alvarez@ri.se

RISE - Research Institutes of Sweden

Electric Power System Unit

Sven Hultins Plats 5,

412 58 Göteborg, Sweden
